@@ -76,7 +76,7 @@ class Scraper:
         if dataType is not None and '[' in dataType: # in the case dataType is a datetime with format (DATE[%Y-%m-%d %H:%M:%S])
             tokens = dataType.split('[')
             dataType = tokens[0]
-            format = dataType[1][:-1]
+            format = tokens[1][:-1]
 
         if dataType == WebScraper.Types.DATE:
             el = Types.to_date(el, format=format)
